@@ -1,7 +1,7 @@
 package Dist::Zilla::Plugin::Depak;
 
-our $DATE = '2015-07-05'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2015-07-06'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,6 +25,7 @@ with (
     },
     'Dist::Zilla::Role::FileGatherer',
     'Dist::Zilla::Role::FileMunger',
+    'Dist::Zilla::Role::PERLANCAR::WriteModules',
 );
 
 has include_script => (is => 'rw');
@@ -87,28 +88,8 @@ sub munge_script {
         $target = $filename;
     }
 
-    # we want to include the built version of dist modules and not the raw
-    # source ones (because we want version numbers to be filled with
-    # OurPkgVersion and so on). but dzil writes the dist to disk at a later
-    # stage. so we dump the modules to a temp dir. but note that we need to pack
-    # the scripts first before munging the modules (replacing #PACKED_MODULES,
-    # #PACKED_DISTS), so the version of modules included in the script won't
-    # have these directives replaced yet.
-    state $has_written_modules;
-    my $mods_tempdir;
-    {
-        last if $has_written_modules++;
-        $mods_tempdir = tempdir(CLEANUP => 1);
-        $self->log_debug(["creating tempdir containing dist modules: %s", $mods_tempdir]);
-        my @modules  = grep { $_->name =~ m!^lib/! } @{ $self->found_files };
-        for my $modobj (@modules) {
-            my ($dir, $name) = $modobj->{name} =~ m!lib/(?:(.*)/)?(.+)!;
-            make_path("$mods_tempdir/$dir") if length($dir);
-            my $target = "$mods_tempdir/$dir/$name";
-            $self->log_debug(["  writing %s", $target]);
-            write_binary($target, $modobj->content);
-        }
-    }
+    $self->write_modules_to_dir;
+    my $mods_tempdir = $self->written_modules_dir;
 
     # the --json output is so that we can read the list of included modules
     my @depak_cmd = (
@@ -199,7 +180,7 @@ Dist::Zilla::Plugin::Depak - Pack dependencies onto scripts during build using '
 
 =head1 VERSION
 
-This document describes version 0.09 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-05.
+This document describes version 0.10 of Dist::Zilla::Plugin::Depak (from Perl distribution Dist-Zilla-Plugin-Depak), released on 2015-07-06.
 
 =head1 SYNOPSIS
 
